==> spip_4.2.13+dfsg.orig.tar.xz: plugins-dist/forum/lang/forum_oc_ni_la.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/forum?lang_cible=oc_ni_la
// ** ne pas modifier le fichier **

return [

	// B
	'bouton_radio_articles_futurs' => 'basta ai articles futurs (minga d’accion sus la basa de donadas).',
	'bouton_radio_articles_tous' => 'ai articles toi sensa excepcion',
	'bouton_radio_articles_tous_sauf_forum_desactive' => 'a toi lu articles, exceptat aquelu que lo sieu forum es desactivat.',
	'bouton_radio_enregistrement_obligatoire' => 'Registrament obligatòri (lu utilizaires si devon abonar en donant la sieu adreiça e-mail avans de poder mandar de contribucions).',
	'bouton_radio_moderation_priori' => 'Moderacion a priòri (li
 contribucions apareisson en public basta se lu administrators
 li an validadi).', # MODIF
	'bouton_radio_modere_abonnement' => 'moderat emb abonament',
	'bouton_radio_modere_posteriori' => 'moderat a posteriòri', # MODIF
	'bouton_radio_modere_priori' => 'moderat a priòri', # MODIF
	'bouton_radio_publication_immediate' => 'Publicar lu messatges sus lo còup
 (li contribucions apareisson a pena mandadi, lu administrators li pòdon
 suprimir pi).',

	// F
	'form_pet_message_commentaire' => 'Un messatge, una remarca?',
	'forum' => 'Forum',
	'forum_acces_refuse' => 'Podètz pus accedir a aquelu forums.',
	'forum_attention_dix_caracteres' => '<b>Atencion!</b> lo vòstre messatge deu tenir aumens dètz caractèrs.',
	'forum_attention_trois_caracteres' => '<b>Atencion!</b> lo vòstre títol deu tenir aumens tres caractèrs.',
	'forum_avez_selectionne' => 'Avètz seleccionat:',
	'forum_cliquer_retour' => 'Clicatz <a href=\'@retour_forum@\'>aicí</a> per contunhar.',
	'forum_forum' => 'forum',
	'forum_info_modere' => 'Aquest forum es moderat a priòri: la vòstra contribucion pareisserà basta après qu’un administrator dau sit l’auga validada.', # MODIF
	'forum_lien_hyper' => '<b>Ligam ipertèxt</b> (opcionau)', # MODIF
	'forum_message_definitif' => 'Messatge definitiu: mandar au sit',
	'forum_message_trop_long' => 'Lo vòstre messatge es tròup lòng. La longor maximala es de 20 000 caractèrs.', # MODIF
	'forum_ne_repondez_pas' => 'Non respondatz a aquel e-mail mas per lo forum a l’adreiça seguenta: ', # MODIF
	'forum_page_url' => '(Se lo vòstre messatge si referisse a un article publicat per lo web, ò a una pàgina que done mai d’informacions, podètz marcar çai sota lo títol de la pàgina e la sieu adreiça.)',
	'forum_poste_par' => 'Messatge poste@parauteur@ que fa seguda au vòstre article.', # MODIF
	'forum_qui_etes_vous' => '<b>Cu siatz?</b> (opcionau)', # MODIF
	'forum_texte' => 'Tèxt dau vòstre messatge:', # MODIF
	'forum_titre' => 'Títol:', # MODIF
	'forum_url' => 'URL:', # MODIF
	'forum_valider' => 'Validar aquela chausida',
	'forum_voir_avant' => 'Veire lo messatge avans de lo mandar', # MODIF
	'forum_votre_email' => 'La vòstra adreiça e-mail:', # MODIF
	'forum_votre_nom' => 'Lo vòstre nom (ò pseudonim):', # MODIF
	'forum_vous_enregistrer' => 'Per participar a
  aqueu forum, d’en primier vos cau registrar. Mercé
  de marcar çai sota l’identificant personau qu’avètz recebut.
 Se non siatz registrat/ada, avètz de',
	'forum_vous_inscrire' => 'v’inscriure.',

	// I
	'icone_poster_message' => 'Postar un messatge',
	'icone_suivi_forum' => 'Seguit dau forum public: @nb_forums@ contribucion(s)',
	'icone_suivi_forums' => 'Sègre/gerir lu forums',
	'icone_supprimer_message' => 'Suprimir aqueu messatge',
	'icone_valider_message' => 'Validar aqueu messatge',
	'info_activer_forum_public' => '<i>Per activar lu forums publics, vorgatz chausir lo sieu mòde de moderacion predefinit:</i>', # MODIF
	'info_appliquer_choix_moderation' => 'Aplicar aquela chausida de moderacion:',
	'info_desactiver_forum_public' => 'Desactivar l’utilizacion dei forums publics. Lu forums publics porràn èstre autorizats au cas per cas sobre lu articles; seràn proïbits sobre li rubricas, brèvas, etc.',
	'info_envoi_forum' => 'Mandadís dei forums ai autors dei articles',
	'info_fonctionnement_forum' => 'Foncionament dau forum:',
	'info_gauche_suivi_forum_2' => 'La pàgina de <i>segut dei forums</i> es una aisina de gestion dau vòstre sit (mas non es un espaci per discutir ò per redigir). Aficha toti li contribucions dau forum public d’aquel article e vos permete de gerir aqueli contribucions.', # MODIF
	'info_liens_syndiques_3' => 'forums',
	'info_liens_syndiques_4' => 'son',
	'info_liens_syndiques_5' => 'forum',
	'info_liens_syndiques_6' => 'es',
	'info_liens_syndiques_7' => 'en espèra de validacion',
	'info_mode_fonctionnement_defaut_forum_public' => 'Mòde de foncionament predefinit dei forums publics',
	'info_option_email' => 'Quora un vesitaire dau sit manda un messatge nòu au forum
 associat a un article, se’n pòu avisar lu autors
 de l’article per e-mail. Desiratz d’utilizar aquela opcion?', # MODIF
	'info_pas_de_forum' => 'Minga de forum',
	'item_activer_forum_administrateur' => 'Activar lo forum dei administrators',
	'item_desactiver_forum_administrateur' => 'Desactivar lo forum dei administrators',

	// L
	'lien_reponse_article' => 'Respòsta a l’article',
	'lien_reponse_breve_2' => 'Respòsta a la brèva',
	'lien_reponse_rubrique' => 'Respòsta a la rubrica',
	'lien_reponse_site_reference' => 'Respòsta au sit referenciat:', # MODIF

	// O
	'onglet_messages_internes' => 'Messatges intèrnes',
	'onglet_messages_publics' => 'Messatges publics',
	'onglet_messages_vide' => 'Messatges sensa tèxt',

	// R
	'repondre_message' => 'Respòndre a aqueu messatge',

	// T
	'titre_cadre_forum_administrateur' => 'Forum privat dei administrators',
	'titre_cadre_forum_interne' => 'Forum intèrne',
	'titre_forum' => 'Forum',
	'titre_forum_suivi' => 'Segut dei forums',
	'titre_page_forum_suivi' => 'Segut dei forums',
];

==> spip_4.4.3+dfsg.orig.tar.xz: plugins-dist/forum/lang/forum_oc_ni_la.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/forum?lang_cible=oc_ni_la
// ** ne pas modifier le fichier **

return [

	// B
	'bouton_radio_articles_futurs' => 'basta ai articles futurs (minga d’accion sus la basa de donadas).',
	'bouton_radio_articles_tous' => 'ai articles toi sensa excepcion',
	'bouton_radio_articles_tous_sauf_forum_desactive' => 'a toi lu articles, exceptat aquelu que lo sieu forum es desactivat.',
	'bouton_radio_enregistrement_obligatoire' => 'Registrament obligatòri (lu utilizaires si devon abonar en donant la sieu adreiça e-mail avans de poder mandar de contribucions).', # MODIF
	'bouton_radio_moderation_priori' => 'Moderacion a priòri (li
 contribucions apareisson en public basta se lu administrators
 li an validadi).', # MODIF
	'bouton_radio_modere_abonnement' => 'moderat emb abonament',
	'bouton_radio_modere_posteriori' => 'moderat a posteriòri', # MODIF
	'bouton_radio_modere_priori' => 'moderat a priòri', # MODIF
	'bouton_radio_publication_immediate' => 'Publicar lu messatges sus lo còup
 (li contribucions apareisson a pena mandadi, lu administrators li pòdon
 suprimir pi).', # MODIF

	// F
	'form_pet_message_commentaire' => 'Un messatge, una remarca?',
	'forum' => 'Forum',
	'forum_acces_refuse' => 'Podètz pus accedir a aquelu forums.',
	'forum_attention_dix_caracteres' => '<b>Atencion!</b> lo vòstre messatge deu tenir aumens dètz caractèrs.',
	'forum_attention_trois_caracteres' => '<b>Atencion!</b> lo vòstre títol deu tenir aumens tres caractèrs.',
	'forum_avez_selectionne' => 'Avètz seleccionat:',
	'forum_cliquer_retour' => 'Clicatz <a href=\'@retour_forum@\'>aicí</a> per contunhar.',
	'forum_forum' => 'forum',
	'forum_info_modere' => 'Aquest forum es moderat a priòri: la vòstra contribucion pareisserà basta après qu’un administrator dau sit l’auga validada.', # MODIF
	'forum_lien_hyper' => '<b>Ligam ipertèxt</b> (opcionau)', # MODIF
	'forum_message_definitif' => 'Messatge definitiu: mandar au sit',
	'forum_message_trop_long' => 'Lo vòstre messatge es tròup lòng. La longor maximala es de 20 000 caractèrs.', # MODIF
	'forum_ne_repondez_pas' => 'Non respondatz a aquel e-mail mas per lo forum a l’adreiça seguenta: ', # MODIF
	'forum_page_url' => '(Se lo vòstre messatge si referisse a un article publicat per lo web, ò a una pàgina que done mai d’informacions, podètz marcar çai sota lo títol de la pàgina e la sieu adreiça.)',
	'forum_poste_par' => 'Messatge poste@parauteur@ que fa seguda au vòstre article.', # MODIF
	'forum_qui_etes_vous' => '<b>Cu siatz?</b> (opcionau)', # MODIF
	'forum_texte' => 'Tèxt dau vòstre messatge:', # MODIF
	'forum_titre' => 'Títol:', # MODIF
	'forum_url' => 'URL:', # MODIF
	'forum_valider' => 'Validar aquela chausida',
	'forum_voir_avant' => 'Veire lo messatge avans de lo mandar', # MODIF
	'forum_votre_email' => 'La vòstra adreiça e-mail:', # MODIF
	'forum_votre_nom' => 'Lo vòstre nom (ò pseudonim):', # MODIF
	'forum_vous_enregistrer' => 'Per participar a
  aqueu forum, d’en primier vos cau registrar. Mercé
  de marcar çai sota l’identificant personau qu’avètz recebut.
 Se non siatz registrat/ada, avètz de',
	'forum_vous_inscrire' => 'v’inscriure.',

	// I
	'icone_poster_message' => 'Postar un messatge',
	'icone_suivi_forum' => 'Seguit dau forum public: @nb_forums@ contribucion(s)',
	'icone_suivi_forums' => 'Sègre/gerir lu forums',
	'icone_supprimer_message' => 'Suprimir aqueu messatge',
	'icone_valider_message' => 'Validar aqueu messatge',
	'info_activer_forum_public' => '<i>Per activar lu forums publics, vorgatz chausir lo sieu mòde de moderacion predefinit:</i>', # MODIF
	'info_appliquer_choix_moderation' => 'Aplicar aquela chausida de moderacion:',
	'info_desactiver_forum_public' => 'Desactivar l’utilizacion dei forums publics. Lu forums publics porràn èstre autorizats au cas per cas sobre lu articles; seràn proïbits sobre li rubricas, brèvas, etc.',
	'info_envoi_forum' => 'Mandadís dei forums ai autors dei articles', # MODIF
	'info_fonctionnement_forum' => 'Foncionament dau forum:',
	'info_gauche_suivi_forum_2' => 'La pàgina de <i>segut dei forums</i> es una aisina de gestion dau vòstre sit (mas non es un espaci per discutir ò per redigir). Aficha toti li contribucions dau forum public d’aquel article e vos permete de gerir aqueli contribucions.', # MODIF
	'info_liens_syndiques_3' => 'forums',
	'info_liens_syndiques_4' => 'son',
	'info_liens_syndiques_5' => 'forum',
	'info_liens_syndiques_6' => 'es',
	'info_liens_syndiques_7' => 'en espèra de validacion',
	'info_mode_fonctionnement_defaut_forum_public' => 'Mòde de foncionament predefinit dei forums publics',
	'info_option_email' => 'Quora un vesitaire dau sit manda un messatge nòu au forum
 associat a un article, se’n pòu avisar lu autors
 de l’article per e-mail. Desiratz d’utilizar aquela opcion?', # MODIF
	'info_pas_de_forum' => 'Minga de forum',
	'item_activer_forum_administrateur' => 'Activar lo forum dei administrators', # MODIF
	'item_desactiver_forum_administrateur' => 'Desactivar lo forum dei administrators', # MODIF

	// L
	'lien_reponse_article' => 'Respòsta a l’article',
	'lien_reponse_breve_2' => 'Respòsta a la brèva',
	'lien_reponse_rubrique' => 'Respòsta a la rubrica',
	'lien_reponse_site_reference' => 'Respòsta au sit referenciat:', # MODIF

	// O
	'onglet_messages_internes' => 'Messatges intèrnes',
	'onglet_messages_publics' => 'Messatges publics',
	'onglet_messages_vide' => 'Messatges sensa tèxt',

	// R
	'repondre_message' => 'Respòndre a aqueu messatge',

	// T
	'titre_cadre_forum_administrateur' => 'Forum privat dei administrators', # MODIF
	'titre_cadre_forum_interne' => 'Forum intèrne',
	'titre_forum' => 'Forum',
	'titre_forum_suivi' => 'Segut dei forums',
	'titre_page_forum_suivi' => 'Segut dei forums',
];
